====
goma
====
	
.. image:: https://img.shields.io/codeship/dff6cee0-3f2b-0135-cf66-3aa03d7e55ef/master.svg
    :target: https://codeship.com//projects/229716
    
generic object mapping algorithms

lib for easy to use complex mappings
